==> coreboot_4.15~dfsg.orig.tar.xz: coreboot-4.15/Documentation/community/forums.md <==
# Our forums

The coreboot community has various venues to help each other and discuss the
direction of our project.

## Mailing list

The first address for coreboot related discussion is our mailing list.
You can subscribe on its
[information page](https://mail.coreboot.org/postorius/lists/coreboot.coreboot.org/) and
read its
[archives](https://mail.coreboot.org/hyperkitty/list/coreboot@coreboot.org/).

## Real time chat

We also have a real time chat room on [IRC](ircs://irc.libera.chat/#coreboot),
also bridged to [Matrix](https://matrix.to/#/#coreboot:libera.chat) and a
[Discord](https://discord.gg/JqT8NM5Zbg) presence. You can also find us on
[OSF Slack](https://osfw.slack.com/), which has channels on many open source
firmware related topics. Slack requires that people come from specific domains
or are explicitly invited. To work around that, there's an
[invite bot](https://slack.osfw.dev/) to let people in.

## Fortnightly coreboot leadership meeting

There's a leadership meeting held every 14 days (currently every other
Wednesday at 10am Pacific Time, usually 18:00 UTC with some deviation
possible due to daylight saving time related shifts). The meeting
is open to everyone and provides a forum to discuss general coreboot
topics, including community and technical matters that benefit from
an official decision.

We tried a whole lot of different tools, but so far the meetings worked
best with [Google Meet](https://meet.google.com/syn-toap-agu),
using [Google Docs](https://docs.google.com/document/d/1NRXqXcLBp5pFkHiJbrLdv3Spqh1Hu086HYkKrgKjeDQ/edit)
for the agenda and meeting minutes. Neither the video conference nor
the document require a Google account to participate, although editing
access to the document is limited to adding comments - any desired
agenda item added that way will be approved in time before the meeting.

==> coreboot-4.18.tar.xz: coreboot-4.18/Documentation/community/forums.md <==
# Our forums

The coreboot community has various venues to help each other and discuss the
direction of our project.

## Mailing list

The first address for coreboot related discussion is our mailing list.
You can subscribe on its
[information page](https://mail.coreboot.org/postorius/lists/coreboot.coreboot.org/) and
read its
[archives](https://mail.coreboot.org/hyperkitty/list/coreboot@coreboot.org/).

## Real time chat

We also have a real time chat room on [IRC](ircs://irc.libera.chat/#coreboot),
also bridged to [Matrix](https://matrix.to/#/#coreboot:libera.chat) and a
[Discord](https://discord.gg/JqT8NM5Zbg) presence. You can also find us on
[OSF Slack](https://osfw.slack.com/), which has channels on many open source
firmware related topics. Slack requires that people come from specific domains
or are explicitly invited. To work around that, there's an
[invite bot](https://slack.osfw.dev/) to let people in.

## Fortnightly coreboot leadership meeting

There's a leadership meeting held every 14 days (currently every other
Wednesday at 10am Pacific Time, usually 18:00 UTC with some deviation
possible due to daylight saving time related shifts). The meeting
is open to everyone and provides a forum to discuss general coreboot
topics, including community and technical matters that benefit from
an official decision.

We tried a whole lot of different tools, but so far the meetings worked
best with [Google Meet](https://meet.google.com/pyt-newq-rbb),
using [Google Docs](https://docs.google.com/document/d/1NRXqXcLBp5pFkHiJbrLdv3Spqh1Hu086HYkKrgKjeDQ/edit)
for the agenda and meeting minutes. Neither the video conference nor
the document require a Google account to participate, although editing
access to the document is limited to adding comments - any desired
agenda item added that way will be approved in time before the meeting.
